#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.11.0
visibility:           public
id:                   lifted-async-0.11.0-E17SmAw3oaXjKAdSvdLSf
key:                  lifted-async-0.11.0-E17SmAw3oaXjKAdSvdLSf
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2025 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  49f68e7ca20274ce884dbf2e2906c9bd
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lifted-async-0.11.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lifted-async-0.11.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lifted-async-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.11.0-E17SmAw3oaXjKAdSvdLSf
depends:
    async-2.2.6-Kykhyh6mBK289NrCI92vZq base-4.18.2.1
    constraints-0.14.3-H2uSlPdvd6VPqTEpJRJ23
    lifted-base-0.2.3.12-Kz94bZTYBQD9uveDVFWUsP
    monad-control-1.0.3.1-5erPYSSULl79PGafwvIfx2
    transformers-base-0.4.6.1-ENHoQKANHRjoYEIjCCdGS

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

